summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Process
diff options
context:
space:
mode:
authorfukachan <fukachan>2004-12-23 12:32:01 +0000
committerfukachan <fukachan>2004-12-23 12:32:01 +0000
commitbe22ec68dec1845daa9eb19f53d8602399ff6888 (patch)
treec56c4d1d92b0a3157c2abe8f3c688232f4224617 /fml/lib/FML/Process
parent397e68ede351f054092b63616d4dbabda36044a8 (diff)
downloadfml8-be22ec68dec1845daa9eb19f53d8602399ff6888.tar.gz
fml8-be22ec68dec1845daa9eb19f53d8602399ff6888.tar.bz2
fml8-be22ec68dec1845daa9eb19f53d8602399ff6888.zip
move Calendar::Lite to FML::Demo::Calendar since this module needs
FML::* class.
Diffstat (limited to 'fml/lib/FML/Process')
-rw-r--r--fml/lib/FML/Process/Calendar.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/fml/lib/FML/Process/Calendar.pm b/fml/lib/FML/Process/Calendar.pm
index 55605a33..081bf0c0 100644
--- a/fml/lib/FML/Process/Calendar.pm
+++ b/fml/lib/FML/Process/Calendar.pm
@@ -3,7 +3,7 @@
# Copyright (C) 2002,2003,2004 Ken'ichi Fukamachi
# All rights reserved.
#
-# $FML: Calendar.pm,v 1.13 2004/02/15 04:38:33 fukachan Exp $
+# $FML: Calendar.pm,v 1.14 2004/07/11 15:43:38 fukachan Exp $
#
package FML::Process::Calendar;
@@ -29,7 +29,7 @@ FML::Process::Calendar -- demonstration of FML module usage.
FML::Process::Calendar is a demonstration module to show fml module
usage. This module provides calendar presentation as a simple
-scheduler based on Calendar::Lite class.
+scheduler based on FML::Demo::Calendar class.
=head1 METHODS
@@ -106,7 +106,7 @@ sub verify_request { 1; }
sub finish { 1; }
# Descriptions: prepare parameters and call Calendar::Lite module.
# we use w3m to show calendar (HTML table).
# Arguments: OBJ($curproc) HASH_REF($args)
# Side Effects: create temporary file and remove it in the last
@@ -125,7 +125,7 @@ sub run
}
use FileHandle;
- use Calendar::Lite;
+ use FML::Demo::Calendar;
# prepare new() argument
$mode = $option->{ m } if defined $option->{ m };
@@ -135,7 +135,7 @@ sub run
schedule_dir => $schedule_dir,
schedule_file => undef,
};
- my $schedule = new Calendar::Lite $schargs;
+ my $schedule = new FML::Demo::Calendar $schargs;
# prepare output channel
my $tmpf = $schedule->tmpfilepath;
@@ -106,7 +106,7 @@ sub verify_request { 1; }
sub finish { 1; }
-# Descriptions: prepare parameters and call Calendar::Lite module.
+# Descriptions: prepare parameters and call FML::Demo::Calendar module.
# we use w3m to show calendar (HTML table).
# Arguments: OBJ($curproc) HASH_REF($args)